@@ -1,8 +1,8 @@
 
 /* gener.c */
 void Distributor(int);
-void m_l_a(int *, int *);
-void l_list_(int *, int *, int *, int *);
+void mla(int *, int *);
+void F77_SUB(llist)(int *, int *, int *, int *);
 void delete_list_array(int *, int *);
 int N_C_R(int, int);
 int F77_CALL(allnr)(int *n, int *r, int *j, int *ifault); 
